@@ -85,6 +85,7 @@ KateViewSpace::KateViewSpace(KateViewManager *viewManager, QWidget *parent)
         makeActive(true);
     });
     hLayout->addWidget(m_tabBar);
+    hLayout->addStretch();
 
     // add Scroll Sync Indicator
     m_scrollSync = new QToolButton(this);
@@ -401,8 +402,9 @@ KTextEditor::View *KateViewSpace::createView(KTextEditor::Document *doc)
     }
 
     connect(v, &KTextEditor::View::cursorPositionChanged, this, [this](KTextEditor::View *view, const KTextEditor::Cursor &newPosition) {
-        if (!m_blockAddHistory && view && view->document())
+        if (!m_blockAddHistory && view && view->document()) {
             addPositionToHistory(view->document()->url(), newPosition);
+        }
     });
 
     // register document
@@ -678,7 +680,7 @@ bool KateViewSpace::acceptsDroppedTab(const QMimeData *md)
 void KateViewSpace::dragEnterEvent(QDragEnterEvent *e)
 {
     if (acceptsDroppedTab(e->mimeData())) {
-        m_dropIndicator.reset(new QRubberBand(QRubberBand::Rectangle, this));
+        m_dropIndicator = std::make_unique<QRubberBand>(QRubberBand::Rectangle, this);
         m_dropIndicator->setGeometry(rect());
         m_dropIndicator->show();
         e->acceptProposedAction();
@@ -1155,8 +1157,9 @@ void KateViewSpace::buildContextMenu(int tabIndex, QMenu &menu)
     aCloseAllTabs->setEnabled(m_tabBar->documentList().size() > 1);
     connect(aCloseAllTabs, &QAction::triggered, this, [this] {
         QTimer::singleShot(0, this, [this]() {
-            for (auto docOrWidget : m_tabBar->documentList()) {
-                int idx = m_tabBar->documentIdx(docOrWidget);
+            // TODO simplify this, we can just iterate 0..tabBar->count();
+            for (auto docOrWid : m_tabBar->documentList()) {
+                int idx = m_tabBar->documentIdx(docOrWid);
                 closeTabRequest(idx);
             }
         });
@@ -1171,9 +1174,9 @@ void KateViewSpace::buildContextMenu(int tabIndex, QMenu &menu)
     }
     auto *doc = docOrWidget.doc();
 
-    auto addActionFromCollection = [this](QMenu *menu, const char *action_name) {
+    auto addActionFromCollection = [this](QMenu *m, const char *action_name) {
         QAction *action = m_viewManager->mainWindow()->action(QLatin1StringView(action_name));
-        auto newAction = menu->addAction(action->icon(), action->text());
+        auto newAction = m->addAction(action->icon(), action->text());
         return newAction;
     };
 
